TextRole enum Requests and results

Who authored a TextMessage in a conversation.

Inheritance
Available extensions

Values

user → const TextRole

A turn written by the human (or calling application).

assistant → const TextRole

A turn returned previously by the assistant model.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TextRole>
A constant List of the values in this enum, in order of their declaration.