VideoGenerator class abstract interface Capabilities

The capability of turning a VideoRequest into video bytes.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateVideo(VideoRequest request, {void onProgress(GenerationProgress)?}) → Future<GenerationResult>
Generates a video for request.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited